@@ -200,7 +200,7 @@ from refinery.lib.tools import documentation, isstream, lookahead, autoinvoke, o
 from refinery.lib.frame import Framed, Chunk
 from refinery.lib.structures import MemoryFile
 from refinery.lib.environment import LogLevel, Logger, environment, logger
-from refinery.lib.types import ByteStr
+from refinery.lib.types import ByteStr, Singleton
 
 
 ByteIO = MemoryFile[ByteStr]
@@ -396,13 +396,14 @@ class Arg(Argument):
         *args   : str,
         help    : Union[omit, str] = omit,
         dest    : Union[omit, str] = omit,
+        nargs   : Union[omit, int, str] = omit,
         metavar : Optional[str] = None,
         group   : Optional[str] = None,
     ):
         """
         Used to add argparse arguments that contain binary data.
         """
-        return cls(*args, group=group, help=help, dest=dest, type=multibin, metavar=metavar or 'B')
+        return cls(*args, group=group, help=help, dest=dest, nargs=nargs, type=multibin, metavar=metavar or 'B')
 
     @classmethod
     def NumSeq(
@@ -496,7 +497,7 @@ class Arg(Argument):
             raise AttributeError(F'The argument with these values has no destination: {self!r}')
 
     @classmethod
-    def Infer(cls, pt: inspect.Parameter):
+    def Infer(cls, pt: inspect.Parameter, module: Optional[str] = None):
         """
         This class method can be used to infer the argparse argument for a Python function
         parameter. This guess is based on the annotation, name, and default value.
@@ -533,8 +534,22 @@ class Arg(Argument):
                 return value
 
         if isinstance(annotation, str):
-            try: annotation = eval(annotation)
-            except Exception: pass
+            symbols = None
+            while symbols is not False:
+                try:
+                    annotation = eval(annotation, symbols)
+                except NameError:
+                    if symbols is not None or module is None:
+                        break
+                    try:
+                        import importlib
+                        symbols = importlib.import_module(module).__dict__
+                    except Exception:
+                        symbols = False
+                except Exception:
+                    pass
+                else:
+                    break
 
         if annotation is not pt.empty:
             if isinstance(annotation, Arg):
@@ -707,10 +722,13 @@ def UnitFilterBoilerplate(
     return peekfilter
 
 
-def _singleton(cls): return cls()
-@_singleton # noqa
-class _NoReverseImplemented:
-    def __call__(*_): raise NotImplementedError
+class MissingFunction(metaclass=Singleton):
+    """
+    A singleton class that represents a missing function. Used internally to
+    indicate that a unit does not implement a reverse operation.
+    """
+    def __call__(*_, **__):
+        raise NotImplementedError
 
 
 class Executable(ABCMeta):
@@ -730,7 +748,7 @@ class Executable(ABCMeta):
 
     _argument_specification: Dict[str, Arg]
 
-    def _infer_argspec(cls, parameters: Dict[str, inspect.Parameter], args: Optional[Dict[str, Arg]] = None):
+    def _infer_argspec(cls, parameters: Dict[str, inspect.Parameter], args: Optional[Dict[str, Arg]], module: str):
 
         args: Dict[str, Arg] = ArgumentSpecification() if args is None else args
 
@@ -741,7 +759,7 @@ class Executable(ABCMeta):
 
         for name in exposed:
             try:
-                argument = Arg.Infer(parameters[name])
+                argument = Arg.Infer(parameters[name], module)
             except KeyError:
                 continue
             args.merge(argument)
@@ -784,7 +802,7 @@ class Executable(ABCMeta):
         if not abstract and Entry not in bases:
             bases = bases + (Entry,)
             if not bases[0].is_reversible:
-                nmspc.setdefault('reverse', _NoReverseImplemented)
+                nmspc.setdefault('reverse', MissingFunction)
         nmspc.setdefault('__doc__', '')
         return super(Executable, mcs).__new__(mcs, name, bases, nmspc)
 
@@ -810,7 +828,7 @@ class Executable(ABCMeta):
                     args[key] = value.__copy__()
                     inherited.append(key)
 
-        cls._infer_argspec(parameters, args)
+        cls._infer_argspec(parameters, args, cls.__module__)
 
         if not abstract and has_keyword:
             @wraps(cls.__init__)
@@ -897,7 +915,7 @@ class Executable(ABCMeta):
         This property is `True` if and only if the unit has a member function named `reverse`. By convention,
         this member function implements the inverse of `refinery.units.Unit.process`.
         """
-        if cls.reverse is _NoReverseImplemented:
+        if cls.reverse is MissingFunction:
             return False
         try:
             return not cls.reverse.__isabstractmethod__
