@@ -3,9 +3,10 @@
 from Crypto.Cipher import AES
 
 from refinery.units.crypto.cipher import StandardBlockCipherUnit
+from refinery.lib.crypto import PyCryptoFactoryWrapper
 
 
-class aes(StandardBlockCipherUnit, cipher=AES):
+class aes(StandardBlockCipherUnit, cipher=PyCryptoFactoryWrapper(AES)):
     """
     AES encryption and decryption.
     """
