@@ -12,14 +12,28 @@ class xtiso(ArchiveUnit):
     """
     Extract files from a ISO archive.
     """
-    def __init__(self, *paths, list=False, join_path=False, drop_path=False, path=b'path', date=b'date',
+    def __init__(
+        self,
+        *paths, list=False, join_path=False, drop_path=False, fuzzy=False, exact=False, regex=False,
+        path=b'path', date=b'date',
         fs: Arg.Choice('-s', metavar='TYPE', choices=_ISO_FILE_SYSTEMS, help=(
             'Specify a file system ({choices}) extension to use. The default setting {default} will automatically '
             'detect the first of the other available options and use it.')) = 'auto'
     ):
         if fs not in _ISO_FILE_SYSTEMS:
             raise ValueError(F'invalid file system {fs}: must be udf, joliet, rr, iso, or auto.')
-        super().__init__(*paths, list=list, join_path=join_path, drop_path=drop_path, path=path, date=date, fs=fs)
+        super().__init__(
+            *paths,
+            list=list,
+            join_path=join_path,
+            drop_path=drop_path,
+            fuzzy=fuzzy,
+            exact=exact,
+            regex=regex,
+            path=path,
+            date=date,
+            fs=fs
+        )
 
     @ArchiveUnit.Requires('pycdlib', optional=False)
     def _pycdlib():
