@@ -13,8 +13,8 @@ from refinery.lib.java import JvClassFile, JvCode, opc
 class jvdasm(PathExtractorUnit):
     """
     Disassembles the JVM bytecode instructions of methods of classes defined in Java class
-    files. The unit is implemented as a `refinery.units.formats.PathExtractorUnit` and each
-    path name corresponds to the name of one method defined in the class file.
+    files. The unit is implemented as a path extractor and each path name corresponds to the
+    name of one method defined in the class file.
     """
     _OPC_STRLEN = max(len(op.name) for op in opc)
 
